==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/memo_folder.php <==
<?php
//==============================================================
// Program Name		: Żҥեʲ̺
// File Name		: memo_folder.php
//--------------------------------------------------------------
// Date             : 2002/02/18
// Author           : M Iura
//--------------------------------------------------------------
// Note				: եɽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc");				// 
require("common_login.php");			// 
require("common_check.inc");			// ̥å


$folder_name = array("", "", "", "", "", "¾", "", "");	// ե̾


define("FOLD_GIF", 			$JJ_IMG_ROOT."body".$JJ_DIR_SEP."memo_s.gif");
define("FOLD_OPEN_GIF", 	$JJ_IMG_ROOT.$JJ_DIR_SEP."mail_open_folder.gif");
define("FOLD_CLOSE_GIF",	$JJ_IMG_ROOT.$JJ_DIR_SEP."mail_close_folder.gif");

define("SPACE_IMG",		$JJ_IMG_ROOT . "spacer.gif");
define("TREE_SPLIT",	$JJ_IMG_ROOT . "body".$JJ_DIR_SEP."tree_split.gif");
define("TREE_END",		$JJ_IMG_ROOT . "body".$JJ_DIR_SEP."tree_end.gif");


if (isset($sel)) {
	setcookie("memo_show", $sel);
}


//--------------------------------------------------------------

//==============================================================
// Function Name    : Ini_set
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Init_set()
{
	global	$TBL_NAME1;
	global	$bgcolor_subete, $bgcolor_sinki, $bgcolor_todo, $bgcolor_tips, $bgcolor_other, $bgcolor_sousin, $bgcolor_zyusin, $bgcolor_sansyou;
	global  $JJ_USERNAME, $JJ_USER_ID;
	
	$TBL_NAME1 = "memo_" . $JJ_USER_ID;
	
	$bgcolor_todo	= "#ffb6c1";
	$bgcolor_tips	= "#ffe4b5";
	$bgcolor_other	= "#b0c4de";
	$bgcolor_sousin	= "#cccc99";
	$bgcolor_zyusin	= "#ccffcc";
	$bgcolor_subete	= "#7fbddb";
	$bgcolor_sinki	= "#CCCCCC";
	$bgcolor_sansyou= "#006699";

}


//==============================================================
// Function Name	: Print_Folder
//--------------------------------------------------------------
// Note				: $sel  =  1  
//							   2  
//							   3  
//							   5  ¾
//							   6  Ѥ
//							   7  
//					:
//==============================================================
Function Print_Folder($sel)
{
	global $folder_name;


	////////////////////////////////////
	// եɽ
	print("<table cellspacing=\"4\" cellpadding=\"0\" border=\"0\" width=\"160\" class=\"color02\">\n");
	print("<tr valign=\"top\">\n");
	print("<td><BR>\n");

	print("<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" WIDTH=\"100%%\">\n");

	print("<tr><td nowrap>\n");
	printf("<img src=\"%s\" border=\"0\" hspace=\"4\" align=\"absmiddle\">\n", FOLD_GIF);
	print("ե<hr WIDTH=\"97%%\"></td>\n");
	print("</tr>\n");

	for($x=0; $x<count($folder_name); $x++)
	{
		if (!empty($folder_name[$x]))
		{
			print("<tr><td nowrap>\n");
			if ($x != 1)
			{
				if ($x + 1 == count($folder_name))
					printf("<img src=\"%s\" border=\"0\" align=\"absmiddle\">\n", TREE_END);
				else
					printf("<img src=\"%s\" border=\"0\" align=\"absmiddle\">\n", TREE_SPLIT);
			}
			if ($x == $sel)
				printf("<img width=\"20\" src=\"%s\" border=\"0\" hspace=\"5\" align=\"absmiddle\">\n", FOLD_OPEN_GIF);
			else
//ե				if ($sel == "1")
//				{
//					printf("<img width=\"20\" src=\"%s\" border=\"0\" hspace=\"5\" align=\"absmiddle\">\n", FOLD_OPEN_GIF);
//				}
//				else
//				{
					printf("<img width=\"20\" src=\"%s\" border=\"0\" hspace=\"5\" align=\"absmiddle\">\n", FOLD_CLOSE_GIF);
//				}
			printf("<A HREF=\"%s?sel=%s\" TARGET=\"content\" onclick=\"window.location='memo_folder.php?sel=%s'\">%s</A>\n", 
											"memo_index.php", $x, $x, $folder_name[$x]);
			print("</td></tr>\n");
		}
	}

	print("</table><BR>\n");

	print("</td></tr></table>\n");

}


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Login_Start(PG_NAME());

if (!isset($memo_show))	$memo_show="1";
if ( (!isset($sel)) || (empty($sel)) ) $sel = $memo_show;

Init_set();

include("common_printheader.inc");

lchk1();

Print_Folder($sel);

include("common_printfooter.inc");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/memo_folder.php <==
<?php
//==============================================================
// Program Name		: Żҥեʲ̺
// File Name		: memo_folder.php
//--------------------------------------------------------------
// Date             : 2002/02/18
// Author           : M Iura
//--------------------------------------------------------------
// Note				: եɽ
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc.php");
require("common_login.php");			// 
require("common_check.inc");			// ̥å


$folder_name = array("", "", "", "", "", "¾", "", "");	// ե̾


define("FOLD_GIF", 			$JJ_IMG_ROOT."body".$JJ_DIR_SEP."memo_s.gif");
define("FOLD_OPEN_GIF", 	$JJ_IMG_ROOT.$JJ_DIR_SEP."mail_open_folder.gif");
define("FOLD_CLOSE_GIF",	$JJ_IMG_ROOT.$JJ_DIR_SEP."mail_close_folder.gif");

define("SPACE_IMG",		$JJ_IMG_ROOT . "spacer.gif");
define("TREE_SPLIT",	$JJ_IMG_ROOT . "body".$JJ_DIR_SEP."tree_split.gif");
define("TREE_END",		$JJ_IMG_ROOT . "body".$JJ_DIR_SEP."tree_end.gif");


if (isset($sel)) {
	setcookie("memo_show", $sel);
}


//--------------------------------------------------------------

//==============================================================
// Function Name    : Ini_set
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Function Init_set()
{
	global	$TBL_NAME1;
	global	$bgcolor_subete, $bgcolor_sinki, $bgcolor_todo, $bgcolor_tips, $bgcolor_other, $bgcolor_sousin, $bgcolor_zyusin, $bgcolor_sansyou;
	global  $JJ_USERNAME, $JJ_USER_ID;
	
	$TBL_NAME1 = "memo_" . $JJ_USER_ID;
	
	$bgcolor_todo	= "#ffb6c1";
	$bgcolor_tips	= "#ffe4b5";
	$bgcolor_other	= "#b0c4de";
	$bgcolor_sousin	= "#cccc99";
	$bgcolor_zyusin	= "#ccffcc";
	$bgcolor_subete	= "#7fbddb";
	$bgcolor_sinki	= "#CCCCCC";
	$bgcolor_sansyou= "#006699";

}


//==============================================================
// Function Name	: Print_Folder
//--------------------------------------------------------------
// Note				: $sel  =  1  
//							   2  
//							   3  
//							   5  ¾
//							   6  Ѥ
//							   7  
//					:
//==============================================================
Function Print_Folder($sel)
{
	global $folder_name;


	////////////////////////////////////
	// եɽ
	print("<table cellspacing=\"4\" cellpadding=\"0\" border=\"0\" width=\"160\" class=\"color02\">\n");
	print("<tr valign=\"top\">\n");
	print("<td><BR>\n");

	print("<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" WIDTH=\"100%%\">\n");

	print("<tr><td nowrap>\n");
	printf("<img src=\"%s\" border=\"0\" hspace=\"4\" align=\"absmiddle\">\n", FOLD_GIF);
	print("ե<hr WIDTH=\"97%%\"></td>\n");
	print("</tr>\n");

	for($x=0; $x<count($folder_name); $x++)
	{
		if (!empty($folder_name[$x]))
		{
			print("<tr><td nowrap>\n");
			if ($x != 1)
			{
				if ($x + 1 == count($folder_name))
					printf("<img src=\"%s\" border=\"0\" align=\"absmiddle\">\n", TREE_END);
				else
					printf("<img src=\"%s\" border=\"0\" align=\"absmiddle\">\n", TREE_SPLIT);
			}
			if ($x == $sel)
				printf("<img width=\"20\" src=\"%s\" border=\"0\" hspace=\"5\" align=\"absmiddle\">\n", FOLD_OPEN_GIF);
			else
//ե				if ($sel == "1")
//				{
//					printf("<img width=\"20\" src=\"%s\" border=\"0\" hspace=\"5\" align=\"absmiddle\">\n", FOLD_OPEN_GIF);
//				}
//				else
//				{
					printf("<img width=\"20\" src=\"%s\" border=\"0\" hspace=\"5\" align=\"absmiddle\">\n", FOLD_CLOSE_GIF);
//				}
			printf("<A HREF=\"%s?sel=%s\" TARGET=\"content\" onclick=\"window.location='memo_folder.php?sel=%s'\">%s</A>\n", 
											"memo_index.php", $x, $x, $folder_name[$x]);
			print("</td></tr>\n");
		}
	}

	print("</table><BR>\n");

	print("</td></tr></table>\n");

}


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================
Login_Start(PG_NAME());

if (!isset($memo_show))	$memo_show="1";
if ( (!isset($sel)) || (empty($sel)) ) $sel = $memo_show;

Init_set();

include("common_printheader.inc");

lchk1();

Print_Folder($sel);

include("common_printfooter.inc");

?>
